@@ -315,7 +315,7 @@ correlation.method = c("pearson","kendall","spearman"))
    if (tail == "left") 
    {
     if(i==1) METHOD<-paste(METHOD, "(left-tailed with Spearman correlation coefficient)")
-    p.value.temp<-spearman.test(d,z)[5]
+    p.value.temp <- cor.test(d, z, method = "spearman")$p.value
     if(correlation < 0)
     {
      p.value<-p.value.temp/2
@@ -334,7 +334,7 @@ correlation.method = c("pearson","kendall","spearman"))
    if (tail == "right") 
    {
     if(i==1) METHOD<-paste(METHOD, "(right-tailed with Spearman correlation coefficient)")
-    p.value.temp<-spearman.test(d,z)[5]
+    p.value.temp <- cor.test(d, z, method = "spearman")$p.value
     if(correlation > 0)
     {
      p.value<-p.value.temp/2
@@ -353,7 +353,7 @@ correlation.method = c("pearson","kendall","spearman"))
    if (tail == "both") 
    {
     if(i==1) METHOD<-paste(METHOD, "(two-tailed with Spearman correlation coefficient)")
-    p.value<-spearman.test(d,z)[5]
+    p.value <- cor.test(d, z, method = "spearman")$p.value
     q.value<-1-p.value 
     log.p.value<-log(p.value)
     log.q.value<-log(q.value)
